summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit6c79d50fa9fbdff7f69ca57a8ab5fcc942375593 (patch)
treef47737d56c3239a0d8bc600674f0ca04b6e30d6e /lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
parent36c36b53a129509d56fdaa0a7c9fcbcacd0c5826 (diff)
downloadtdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.tar.gz
tdewebdev-6c79d50fa9fbdff7f69ca57a8ab5fcc942375593.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
index fde6d3b7..4a6bb0a4 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
@@ -49,7 +49,7 @@ public:
/**
* Constructor
*/
- KMdiChildFrmCaption( KMdiChildFrm *tqparent );
+ KMdiChildFrmCaption( KMdiChildFrm *parent );
/**
* Destructor
@@ -89,7 +89,7 @@ protected:
virtual void mousePressEvent( TQMouseEvent * );
/**
* Calls maximizePressed of the tqparent widget ( KMdiChildFrm )
*/
virtual void mouseDoubleClickEvent( TQMouseEvent * );
@@ -118,7 +118,7 @@ public:
protected: // Protected attributes
/**
- * tqparent widget
+ * parent widget
*/
KMdiChildFrm *m_pParent;
@@ -128,7 +128,7 @@ protected: // Protected attributes
bool m_bActive;
/**
* the position offset related to its tqparent widget (internally used for translating mouse move positions
*/
TQPoint m_offset;
@@ -89,7 +89,7 @@ protected:
virtual void mousePressEvent( TQMouseEvent * );
/**
- * Calls maximizePressed of the tqparent widget ( KMdiChildFrm )
+ * Calls maximizePressed of the parent widget ( KMdiChildFrm )
*/
virtual void mouseDoubleClickEvent( TQMouseEvent * );
@@ -128,7 +128,7 @@ protected: // Protected attributes
bool m_bActive;
/**
- * the position offset related to its tqparent widget (internally used for translating mouse move positions
+ * the position offset related to its parent widget (internally used for translating mouse move positions
*/
TQPoint m_offset;